<?php

namespace Drupal\Tests\fillpdf\Traits;

trait TestFillPdfTrait {

  protected function configureBackend() {
    // FillPDF needs to be configured.
    /** @var \Drupal\Core\Config\Config $fillpdf_settings */
    $fillpdf_settings = $this->container->get('config.factory')
      ->getEditable('fillpdf.settings')
      ->set('scheme', 'public')
      ->set('backend', 'test');
    $fillpdf_settings->save();
  }

  protected function initializeUser() {
    // Create and log in our privileged user.
    $account = $this->drupalCreateUser([
      'access administration pages',
      'administer pdfs',
    ]);
    $this->drupalLogin($account);
  }

  protected function uploadTestPdf() {
    /** @var \Drupal\Core\File\FileSystem $file_system */
    $file_system = $this->container->get('file_system');
    // Upload a test file.
    $edit = array(
      'files[upload_pdf]' => $file_system->realpath(drupal_get_path('module', 'fillpdf') . '/tests/modules/fillpdf_test/files/fillpdf_test_v3.pdf'),
    );
    $this->drupalPostForm('admin/structure/fillpdf', $edit, 'Upload');
    $this->assertSession()->statusCodeEquals(200);
  }

  /**
   * @return mixed
   */
  protected function getLatestFillPdfForm() {
    // Get the fid of the uploaded file to construct the link.
    $entity_query = $this->container->get('entity_type.manager')
      ->getStorage('fillpdf_form')
      ->getQuery();
    $max_fid_after_result = $entity_query
      ->sort('fid', 'DESC')
      ->range(0, 1)
      ->execute();
    return reset($max_fid_after_result);
  }

}
